@@ -1,7 +1,7 @@
 from .constraints import *
 from .downloads import *
 from .utils import *
-from .minimise import *
+from .minimize import *
 from .faux_selectors import *
 from .ss_changes import *
 try:
